@@ -37,11 +37,13 @@ if (defined($new_x)) {
     $F = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev",'FILE_MODE' => $file, 'SHOW_ERRORS' => 0);
 }
 
-$SIG{'QUIT'} = sub {$F->clip_reset();$F->cls('ON'); exit(0);};
-$SIG{'INT'}  = sub {$F->clip_reset();$F->cls('ON'); exit(0);};
+$SIG{'QUIT'} = sub {$F->clip_reset();$F->cls('ON'); exec('reset');};
+$SIG{'INT'}  = sub {$F->clip_reset();$F->cls('ON'); exec('reset');};
 
 my $screen_width  = $F->{'XRES'};
 my $screen_height = $F->{'YRES'};
+# Everything is based on a 1920x1080 screen, but different resolutions
+# are mathematically scaled.
 my $xm            = $F->{'XRES'} / 1920;
 my $ym            = $F->{'YRES'} / 1080;
 my $XX            = $screen_width;
@@ -106,7 +108,7 @@ unmask_drawing();
 $F->clip_reset();
 $F->cls('ON');
 
-exit(0);
+exec('reset');
 
 sub color_mapping {
     print_it($F,'Color Mapping Test -> Red-Green-Blue');
@@ -1107,7 +1109,7 @@ sub and_drawing {
 }
 
 sub mask_drawing {
-    print_it($F, 'Testing MASK Drawing Mode (This is SLOOOOW)');
+    print_it($F, 'Testing MASK Drawing Mode (This may be SLOW)');
     my $h = int($YY - $F->{'Y_CLIP'});
     my $image1 = $F->load_image(
         {
@@ -1173,7 +1175,7 @@ sub mask_drawing {
 }
 
 sub unmask_drawing {
-    print_it($F, 'Testing UNMASK Drawing Mode (This is SLOOOW)');
+    print_it($F, 'Testing UNMASK Drawing Mode (This may be SLOW)');
     my $h = int($YY - $F->{'Y_CLIP'});
     my $image1 = $F->load_image(
         {
@@ -1329,6 +1331,8 @@ This tells the script to tell the Graphics::Framebuffer module to simulate a dev
 
 Any benchmarking numbers are written to STDERR.  Animations have benchmarking.
 
+Place any other animated GIFs in the C<"examples/images/"> directory and it will include it in the testing
+
 =head1 AUTHOR
 
 Richard Kelsch <rich@rk-internet.com>
